# Evolutionary Algorithm Optimization (EAO)

Package for optimization using Evolutionary Algorithms (EA), providing base classes for individuals and an evaluation module.


## Version History

* **0.4** Removed necessity to manually assign `loss_` attribute
* **0.5** Added extensive logging capabilities; will be cleaned up a little in later versions
* **0.6** Fixed critical bug that affects optimization with more than one parent


## Documentation

Coming soon (sorry, I know this is terrible..)
